@@ -121,7 +121,7 @@ class CentralModel:
 
         return t
 
-    def sample(self, u, v):
+    def sample(self, u, v, normalize=False):
         """Used to sample the b-spline surface. \n
 
         Keyword arguments: \n
@@ -146,6 +146,9 @@ class CentralModel:
                 aij = self.a[i, j]
                 res += np.multiply(aij, Bh[i] * Bv[j])
 
+        if normalize and np.linalg.norm(res) > 0:
+            res /= np.linalg.norm(res)
+
         return res
 
     def sample_grid(self):
@@ -230,7 +233,7 @@ class CentralModel:
 
         return np.transpose(np.meshgrid(x, y))
 
-    def forward_sample(self, ray, x0=None, use_bounds=True, method='Powell', tol=None, options={}, return_results=False):
+    def forward_sample(self, ray, x0=None, use_bounds=True, method='Powell', tol=None, options={}, return_results=False, normalize=True):
         """Returns the corresponding pixel coordinates for a given ray. \n
 
         Keyword arguments: \n
@@ -239,15 +242,17 @@ class CentralModel:
         use_bounds: Sets the image dimensions as bounds for the optimizer. \n
         method: Optimization method from scipy's \'minimize\'. \n
         options: Options for the optimization. See scipu's \'minimize\'. \n
-        return_resultsc: If True the function returns the result of the minimization. Otherwise the function just returns the pixel coordinates of the ray.
+        return_results: If True the function returns the result of the minimization. Otherwise the function just returns the pixel coordinates of the ray.
         """
         assert isinstance(ray, np.ndarray) and ray.size == 3, '\'ray\' must be an array containing the direction of a 3d ray.'
 
-        ray = ray.reshape((3,))
+        if normalize:
+            ray = ray.reshape((3,))
+            ray /= np.linalg.norm(ray)
 
-        def fun(params, ray):
+        def fun(params, ray, normalize):
             u, v = params[0], params[1]
-            s = self.sample(u, v)
+            s = self.sample(u, v, normalize=normalize)
 
             return np.linalg.norm(s - ray)
 
@@ -258,7 +263,7 @@ class CentralModel:
         if use_bounds and not method in ['Powell']:
             bounds = np.array([(0, self.image_width), (0, self.image_height)])
 
-        res = minimize(fun, x0, args=(ray), tol=tol, bounds=bounds, method=method, options=options)
+        res = minimize(fun, x0, args=(ray, normalize), tol=tol, bounds=bounds, method=method, options=options)
 
         if return_results:
             return res
@@ -425,14 +430,14 @@ if __name__ == '__main__':
         with open('temp_file.npz', 'rb') as file:
             cm = cm_load(file)
 
-        ray = np.array([[4], [2], [8]])
+        ray = np.array([[4.0], [2.0], [8.0]])
 
         options = {'disp': True,'xtol': 1e-8, 'ftol': 1e-8}
         u, v = cm.forward_sample(ray, method='Powell', tol=1e-8, options=options)
 
-        s = cm.sample(u, v)
+        s = cm.sample(u, v, normalize=True).reshape((3,1))
 
-        print(ray, s, ray-s)
+        print('Original ray:\n{}\n\nSampled ray:\n{}\n\nDiff:\n{}\n'.format(ray, s, ray-s))
 
     ## Real world forward sampling test
     if False:
